@@ -23,7 +23,7 @@ class Virus():
     """
     This is the class Virus. Pretty basic stuff.
     """
-    def open_website(self, duration):
+    def open_website(self, duration:float):
         t = 0
         duration = duration*60
         while t <= duration:
